@@ -1,12 +1,12 @@
 from __future__ import print_function
 
-from django.core.management.base import NoArgsCommand
+from django.core.management.base import BaseCommand
 
 from django_file_form.models import UploadedFile
 
 
-class Command(NoArgsCommand):
-    def handle_noargs(self, **options):
+class Command(BaseCommand):
+    def handle(self, *args, **options):
         deleted_files = UploadedFile.objects.delete_unused_files()
 
         verbosity = options.get('verbosity')
@@ -14,4 +14,4 @@ class Command(NoArgsCommand):
             if not deleted_files:
                 print('No files deleted')
             else:
-                print('Deleted files: %s' % ', '.join(deleted_files))
\ No newline at end of file
+                print('Deleted files: {0!s}'.format(', '.join(deleted_files)))
